// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as widgets from '@jupyter-widgets/controls';
import * as base from '@jupyter-widgets/base';
import * as baseManager from '@jupyter-widgets/base-manager';
import * as bqscales from 'bqscales';
let numComms = 0;
export class MockComm {
    constructor() {
        this._on_msg = null;
        this._on_open = null;
        this._on_close = null;
        this.comm_id = `mock-comm-id-${numComms}`;
        numComms += 1;
    }
    on_open(fn) {
        this._on_open = fn;
    }
    on_close(fn) {
        this._on_close = fn;
    }
    on_msg(fn) {
        this._on_msg = fn;
    }
    _process_msg(msg) {
        if (this._on_msg) {
            return this._on_msg(msg);
        }
        else {
            return Promise.resolve();
        }
    }
    open() {
        if (this._on_open) {
            this._on_open();
        }
        return '';
    }
    close() {
        if (this._on_close) {
            this._on_close();
        }
        return '';
    }
    send() {
        return '';
    }
}
export class DummyManager extends baseManager.ManagerBase {
    constructor(library) {
        super();
        this.el = window.document.createElement('div');
        window.document.body.appendChild(this.el);
        this.library = library;
    }
    // @ts-ignore
    display_view(msg, view, options) {
        return __awaiter(this, void 0, void 0, function* () {
            yield Promise.resolve(view).then((view) => __awaiter(this, void 0, void 0, function* () {
                this.el.appendChild(view.el);
                view.on('remove', () => console.log('view removed', view));
                window.last_view = view;
                view.trigger('displayed');
                if (view['renderImpl']) {
                    view['attached'] = true;
                    yield view['renderImpl']();
                }
                return view.el;
            }));
        });
    }
    loadClass(className, moduleName, moduleVersion) {
        if (moduleName === '@jupyter-widgets/base') {
            if (base[className]) {
                return Promise.resolve(base[className]);
            }
            else {
                return Promise.reject(`Cannot find class ${className}`);
            }
        }
        else if (moduleName === '@jupyter-widgets/controls') {
            if (widgets[className]) {
                return Promise.resolve(widgets[className]);
            }
            else {
                return Promise.reject(`Cannot find class ${className}`);
            }
        }
        else if (moduleName === 'bqscales') {
            if (bqscales[className]) {
                return Promise.resolve(bqscales[className]);
            }
            else {
                return Promise.reject(`Cannot find class ${className}`);
            }
        }
        else if (moduleName in this.library) {
            return Promise.resolve(this.library[moduleName][className]);
        }
        else {
            return Promise.reject(`Cannot find module ${moduleName}`);
        }
    }
    _get_comm_info() {
        return Promise.resolve({});
    }
    _create_comm() {
        return Promise.resolve(new MockComm());
    }
}
//# sourceMappingURL=dummy-manager.js.map