var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { expect } from 'chai';
import { DummyManager } from './dummy-manager';
import * as bqplot from '..';
import { create_figure_image, create_model } from './widget-utils';
import { testX, testY, pixelRed, redPngData, redPngDataUrl } from './common';
import * as d3Timer from 'd3-timer';
describe('image >', () => {
    beforeEach(function () {
        return __awaiter(this, void 0, void 0, function* () {
            this.manager = new DummyManager({ bqplot: bqplot });
        });
    });
    it('image buffer', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const png_buffer = new DataView(new Uint8Array(redPngData).buffer);
            const ipywidgetImage = yield create_model(this.manager, '@jupyter-widgets/controls', 'ImageModel', 'ImageView', 'im1', {
                value: png_buffer,
                format: 'png',
            });
            const { figure } = yield create_figure_image(this.manager, ipywidgetImage);
            d3Timer.timerFlush(); // this makes sure the animations are all executed
            const canvas = yield figure.get_rendered_canvas();
            const context = canvas.getContext('2d');
            const pixel = context.getImageData(testX, testY, 1, 1);
            expect(Array.prototype.slice.call(pixel.data)).to.deep.equals(pixelRed);
        });
    });
    it('image data url', function () {
        return __awaiter(this, void 0, void 0, function* () {
            const png_buffer = new DataView(new TextEncoder().encode(redPngDataUrl).buffer);
            const ipywidgetImage = yield create_model(this.manager, '@jupyter-widgets/controls', 'ImageModel', 'ImageView', 'im1', {
                value: png_buffer,
                format: 'url',
            });
            const { figure } = yield create_figure_image(this.manager, ipywidgetImage);
            d3Timer.timerFlush(); // this makes sure the animations are all executed
            const canvas = yield figure.get_rendered_canvas();
            const context = canvas.getContext('2d');
            const pixel = context.getImageData(testX, testY, 1, 1);
            expect(Array.prototype.slice.call(pixel.data)).to.deep.equals(pixelRed);
        });
    });
});
//# sourceMappingURL=image.js.map